@@ -35,13 +35,10 @@ def capture(stream_url, output_jpg, timeout=10, type='jpg'):
         if not error_log:
             result = True
             break
+
+        if os.path.isfile(output_jpg):
+            os.remove(output_jpg)
+
         time.sleep(1)
 
-    if not result:
-        # 截图时出现错误日志，这里将会删除无效的图片
-        try:
-            os.remove(output_jpg)
-        except Exception:
-            pass
-
     return result
